@@ -1,4 +1,4 @@
-# Copyright © 2012-2019 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2020 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -39,7 +39,7 @@ from lib import paths as pathmod
 from lib import tags
 from lib import terminal
 
-__version__ = '0.25.8'
+__version__ = '0.25.9'
 
 def initialize_terminal():
     if sys.stdout.isatty():
@@ -172,8 +172,11 @@ class VersionAction(argparse.Action):
             # __version__ is available only since rply 0.7.5:
             # https://github.com/alex/rply/pull/58
             pass
+        if sys.version_info >= (3, 8):
+            import importlib.metadata  # pylint: disable=import-outside-toplevel,import-error,no-name-in-module
+            return importlib.metadata.version('rply')  # pylint: disable=no-member
         try:
-            import pkg_resources
+            import pkg_resources  # pylint: disable=import-outside-toplevel
             [dist, *rest] = pkg_resources.require('rply')
             del rest
         except ImportError:
